/* 
-------- Function: -----------------------------------------------------------------------

     CheckParams


-------- Description: --------------------------------------------------------------------

     This subroutine validates the input parameters used by the SPIHIST task.  It also 
     validates the start and stop times, and the output format option).


-------- Functions called: ---------------------------------------------------------------

   SPI Functions:
      DispMsg        --  Writes messages to the screen and a log file
      GetRange       --  checks the validity of input string and parses it to convert it 
                         to integer range arrays


-------- Usage: --------------------------------------------------------------------------
 
   int CheckParams(outputParsPtr pOutput, eventCriteriaPtr pEventcriteria)

   Input Parameters:		 
              outputParsPtr pars
              ------------------
       FORMAT        char      : Format of the output file (ISDC/PHA)
       DTYPE        int        : Flag to denote counts (1) or count rates (2) or count 
                                 rates per energy (3)

   Output Parameters:
       STATUS        int       : 0=OK


-------- Include files -------------------------------------------------------------------

   "spihist.h"


-------- Authors/Modification History: ---------------------------------------------------

   Craig Gordon (2.2.1; Nov 02) ; removal of tstart, tstop checks
   Craig Gordon (2.2.0; Sep 02) ; verify range of dtype
   Sandhia Bansal  (1.0.0; Aug 00)


--------------------------------------------------------------------------------------- */

#include "spihist.h"


int CheckParams(outputParsPtr pOutput, eventCriteriaPtr pEventcriteria)
{
   int   status=ISDC_OK;

   char  message[DAL_MAX_STRING];
   char  *program="CheckParams";



   if (status == ISDC_OK)
   {
      if (strcmp(pOutput->format, "PHA")==0)
      {
	 if (pOutput->dtype < 1 || pOutput->dtype > 3)
	 {
            strcpy(message,program);
	    strcat(message,": dtype parameter must be 1-3");
	    status = SPI_INVALID_PARAMETER;
	    DispMsg(Error_2, message, status, program, WTCHATTER);
	    return status;
	 }
      }
      status = SPI_INVALID_PARAMETER;

      if ((strcmp(pOutput->format, "ISDC")==0) || 
	  (strcmp(pOutput->format, "PHA")==0))
      { 
	 if ((strcmp(pEventcriteria->psdType, "RAW")==0) ||
	     (strcmp(pEventcriteria->psdType, "COR")==0) ||
	     (strcmp(pEventcriteria->psdType, " ")==0) ||
	     (strcmp(pEventcriteria->psdType, "")==0))
	    status = ISDC_OK;

	 else
	 {
	    strcat(strcpy(message, program), ": Invalid PSD flag.");
	    DispMsg(Error_2, message, status, program, WTCHATTER);
	 }
      }

      else
      {
	 strcat(strcpy(message, program),
		": Invalid output file format.");
	 DispMsg(Error_2, message, status, program, WTCHATTER);
      }
   }

   return(status);
}

