/*----------- Function -------------------------------------------------

    ColNameToIndex
    
------------- Description ----------------------------------------------

    Given the name string of a column in a DalTable, return the
    index number of that column.
    
------------------------------------------------------------------------
   
   Input Parameters:
      pTable            dal_element* :Pointer to Dal Table.
      colName           char*        :Name of column in the table.
   Output Parameters:
   
   Return Value:
      int index of column (1-based)
      0 if not found.
   
------------- Authors/Modification History: ----------------------------

   Craig Gordon  (3.1.1; Aug 03)

------------------------------------------------------------------------
*/   
#include "spihist.h"

int ColNameToIndex(dal_element *pTable, char *colName)
{
   int i;
   int nCols=0;
   int found=0;
   int status = ISDC_OK;
   char currName[DAL_MAX_STRING];
   /* These are dummy variables only needed for the 
      DALtableGetColStruct call. */
   long numBins=0;
   dal_dataType type;
   long binSize=0;
   int varLength;
   
   status = DALtableGetNumCols(pTable, &nCols, status);
   if (status == ISDC_OK)  
   {
      for (i=1; i<=nCols; ++i)
      {
         DALtableGetColStruct(pTable, i, &numBins, currName, &type,
                           &binSize, &varLength, status);
         if (!strcmp(currName,colName))
         {
            found = i;
            break;
         }
      }
   }
   return found;
}
