/*----------- Function -------------------------------------------------

   CopyEboundsExt

------------- Description ----------------------------------------------

   Copies the energy boundaries extension from the input observation group
   to the PHA-II output file of spihist, and modifies certain keywords
   as necessary.
------------------------------------------------------------------------
   
   Input Parameters:
      INPUTDS	   dal_element		:Pointer to the input data structure.
      PARENT	   dal_element		:Output group to which this extension
      					   is attached.
      PHEADER	   headerParsPtr
   
   
------------- Authors/Modification History: ----------------------------

   Craig Gordon (3.0.8; May 03)
   
------------------------------------------------------------------------
*/   
#include "spihist.h"

void CopyEboundsExt(dal_element *inputDS, dal_element *parent, headerParsPtr
		pHeader, memoryPtr *pBase, int chatter)
{
   int                status=ISDC_OK;
   
   char               *program="CopyEboundsExt";
   char               comment[FLEN_COMMENT];
   char               message[DAL_BIG_STRING];
   char		      *templ="SPI.-EBDS-SET";
   dal_element *inEbds=NULL;
   dal_element *doomed=NULL;
   dal_element *pTable=NULL;
   
   /* No test is performed here for existence of input ebounds extension.
      It was done much earlier in the program, in ReadBinFile */
   DALobjectFindElement(inputDS, templ, &inEbds, status);
   
   status = DALobjectFindElement(parent, templ, &doomed, status); 
   if (status == DAL_ELEMENT_NOT_FOUND)
   {
      status = ISDC_OK;
   }
   else if (status == ISDC_OK && doomed)
   {
      // Remove existing ebounds table.
      DALtableDelete(doomed, status);
   }
   else
   {
      strcpy(message,"Error initializing CopyEboundsExt");
      Cleanup(status, message, *pBase, program);
   }
   status = DALtableCopy(inEbds, parent, NULL, ACCESS_UNKNOWN, &pTable, status);
   if (status != ISDC_OK)
   {
      strcpy(message,"Error while copying energy bounds extension to output.");
      Cleanup(status, message, *pBase, program);
   }
   
   strcpy(comment, "Program creating this FITS file");
   PutKeyword(pTable, "CREATOR", (void *) pHeader->tskstr, DAL_CHAR, comment, program);

   
   CommonStampObject(pTable, "", status);
   strcpy(message, " ... Successfully written the EBOUNDS extension");
   DispMsg(Log_1, message, status, program, chatter);
}
