/* 
-------- Function: -----------------------------------------------------------------------

     CopyKeywords


-------- Description: --------------------------------------------------------------------

     This subroutine opens up the EVENTS extension and copies some of the attributes
     (TIMESYS, TIMEUNIT, MJDREF, CLOCKAPP, TIMEREF, and TASSIGN) from the input FITS file
     to the current data object in the output file.


-------- Functions called: ---------------------------------------------------------------

   SPI Functions:
      Cleanup                -- Deallocates all memory allocated during the current run in
                                the event of an error

   DAL3 Functions:
      DAL3GENattributeCopy   --  Copies keyword from input object to output


-------- Usage: --------------------------------------------------------------------------

   void CopyKeywords(dal_element *inputDS, dal_element *pTable, memoryPtr pBase)

   Input Parameters:
       INPUTDS       dal_element   : Pointer to the input Observation group DOL
       PTABLE        dal_element   : Pointer to the output dal element
       PBASE         memoryPtr     : Pointer to the list that keeps track of allocated
                                     memory


-------- Include files -------------------------------------------------------------------

   "spihist.h"


-------- Authors/Modification History: ---------------------------------------------------

   Craig Gordon (2.1.4; Oct 01) - condensed into 1 attribute copy call.
   Sandhia Bansal  (1.0.0; Aug 00)


--------------------------------------------------------------------------------------- */

#include "spihist.h"


void CopyKeywords(dal_element *inputDS, dal_element *pTable, memoryPtr pBase)
{
   int   status=ISDC_OK;

   char  message[DAL_BIG_STRING];
   char  *program="CopyKeywords";



   /* Copy TIMESYS, TIMEUNIT, MJDREF, CLOCKAPP, TIMEREF, and TASSIGN to the
      output extension */
   
   status = DAL3GENattributeCopy(inputDS, pTable, "TIMESYS,TIMEUNIT,MJDREF,CLOCKAPP,TIMEREF,TASSIGN", status);

   
   if (status != ISDC_OK)
   {
      strcpy(message, "Error while copying Spec Keywords");
      Cleanup(status, message, pBase, program);
   }
}
