/* 
-------- Function: -----------------------------------------------------------------------

     CopyRaDec


-------- Description: --------------------------------------------------------------------

     This program copies x,y-ra,dec to an array.  It also calculates the y-ra, dec from 
     x,y-ra,dec.


-------- Functions called: ---------------------------------------------------------------

   Spihist Functions:
      YraDec           --  Calculates y-ra/dec from x,z-ra/dec values


--------- Usage: -------------------------------------------------------------------------

   void CopyRaDec(int pointingNum, pointingInfoPtr pDither)

   Input Parameters:
       POINTINGNUM   int                 : Index to the pointing in the SPI.-OBS.-PNT 
                                           extension

              pointingInfoPtr pars
	      --------------------
       XRA,XDEC, ZRA,ZDEC     double     : x,z-ra/dec in degrees


   Output Parameters:
              pointingInfoPtr pars
	      --------------------
       YRA, YDEC              double     : y-ra/dec in degrees
       RADEC                  double     : Array containing x,y,z-ra,dec values


-------- Include files -------------------------------------------------------------------

   "spihist.h"


-------- Authors/Modification History: ---------------------------------------------------

   Sandhia Bansal  (1.0.0; Aug 00)


-------------------------------------------------------------------------------------- */

#include "spihist.h"


void CopyRaDec(int pointingNum, pointingInfoPtr pDither)
{
   pDither->raDec[0] = pDither->xRa[pointingNum];
   pDither->raDec[1] = pDither->xDec[pointingNum];
   pDither->raDec[4] = pDither->zRa[pointingNum];
   pDither->raDec[5] = pDither->zDec[pointingNum]; 

   /* Calculate yRa and yDec from x and z ra/dec */
   YraDec(pDither->xRa[pointingNum], pDither->xDec[pointingNum], 
	  pDither->zRa[pointingNum], pDither->zDec[pointingNum],
	  &pDither->raDec[2], &pDither->raDec[3]);
}
