/* 
-------- Function: -----------------------------------------------------------------------

     DeleteColumn


-------- Description: --------------------------------------------------------------------

     This function deletes the specified columns from the table.


-------- Functions called: ---------------------------------------------------------------

   SPI  Functions:
      Cleanup                 -- Deallocates all memory allocated during the current run 
                                 in the event of an error and exits the program

   DAL Functions:
      DALtableDeleteCol       -- Deletes a column from the current table
 

-------- Usage: --------------------------------------------------------------------------

   void DeleteColumn(memoryPtr *pBase, dal_element *pTable, char *colName)

   Input Parameters:
       PBASE        memoryPtr    : Pointer to the list that keeps track of allocated
                                   memory
       PTABLE       dal_element  : Pointer to the table from which column needs to be
                                   deleted
       COLNAME      char         : Name of column to be deleted


-------- Include files -------------------------------------------------------------------

   "spihist.h"


-------- Authors/Modification History: ---------------------------------------------------

   Sandhia Bansal  (1.0.0; Nov 00)


--------------------------------------------------------------------------------------- */

#include "spihist.h"


void DeleteColumn(memoryPtr *pBase, dal_element *pTable, char *colName)
{
   int    status=ISDC_OK;

   char   message[DAL_MAX_STRING];
   char   *program="DeleteColumn";


   status = DALtableDelCol(pTable, colName, 0, status);
   if (status != ISDC_OK)
   {
      sprintf(message, "failed to delete %s column", colName);
      Cleanup(status, message, *pBase, program);
   }
}
