/* 
-------- Function: -----------------------------------------------------------------------

    DetInsert  


-------- Description: --------------------------------------------------------------------

     The program recursively inserts a new node in the list.  The node consists of a PSD 
     flag (0/1 for PSD data and -1 for SINGLE-HI_MULT data), the pseudo detector number 
     and ids of the detectors that constitute this pseudo detector number.


-------- Functions called: ---------------------------------------------------------------

   SPI Functions:
      Allocate             -- Allocates specified number of bytes and keeps track of all
                              allocated memory during a run


-------- Usage: --------------------------------------------------------------------------

   void DetInsert(memoryPtr *pBase, memoryPtr *pLast, int mult, int detid, char *detcode,
                  pseudoDetPtr *detList)

   Input Parameters:
       PBASE         memoryPtr       : Pointer to the list that keeps track of allocated
                                       memory
       PLAST         memoryPtr      : Pointer to the current node in the linked list 
                                       pointed to by BASENODEPTR
       MULT          int             : 0: PSD data
                                       1-6 : SINGLE, DOUBLE, TRIPLE, QUADRUPLE, QUINTUPLE,
				       and HI_MULT data repectively
       DETID         int             : Pseudo detector number
       DETCODE       string          : String consisting of real detector ids
       DETLIST       pseudoDetPtr    : Pointer to the first node in the list


   Output Parameters:
       DETLIST       pseudoDetPtr    : Pointer to the first node in the list


-------- Include files -------------------------------------------------------------------

   "spihist.h"


-------- Authors/Modification History: ---------------------------------------------------
   
   Craig Gordon  (2.1.3; Oct 01)
   Craig Gordon  (2.1.1; Aug 01)
   Sandhia Bansal  (1.0.0; Aug 00)


--------------------------------------------------------------------------------------- */

#include "spihist.h"



void DetInsert(memoryPtr *pBase, memoryPtr *pLast, int mult, int detid, char *detcode,
	       pseudoDetPtr *detList)
{
   int                  i=0, j=0;
   int                  idet=0;
   int                  sz=0;

   char                 *program="DetInsert";
   char                 str[3];
   char			psdFlag[2];

   static pseudoDetPtr  temp=NULL;


   /*  If detector is 0-18 psd+singles combo, do nothing and return. */
   if (mult == 0 && strlen(detcode) <= 2)
      return;
      
   /* if first node then create a new pseudo detector node and insert it in detList */
   if (*detList == NULL)
   {
      /* Insert node at beginning of the linked list */
      temp = NULL;
      Allocate(program, "-temp", 0, sizeof(PSEUDODETNODE), (void **) &temp, pBase, pLast);

      temp->next      = NULL;
      temp->psdFlag   = -1;
      temp->pseudoDet = detid;
      temp->detectors = NULL;

      sz = Max(1, mult);   /* handle mult==0 (PSD SINGLE) */
      Allocate(program, "-detectors", 0, sz*sizeof(int), (void **) &temp->detectors, pBase,
	       pLast);
      
      str[2] = '\0';
      psdFlag[1] = '\0';

      if (mult == 0)   /* PSD SINGLE event */
      {
        /* detectors are PSD (1000-1018 or 1100-1118) */ 
	
	 psdFlag[0] = detcode[1];
         temp->psdFlag = atoi(psdFlag);

	 str[0] = detcode[2];
	 str[1] = detcode[3];
	 temp->detectors[0] = atoi(str);
      }

      else if (mult == 1)   /* SINGLE events (1900-1918)*/
      {
         str[0] = detcode[2];
	 str[1] = detcode[3];
	 temp->detectors[0] = atoi(str);
      }

      else if (mult >= 2)   /* events are of higher multiplicity than 1 */
      {
	 i = 1, idet = 0;
	 for (j=0; j<mult; j++)
	 {
	    str[0] = detcode[i];
	    str[1] = detcode[i+1];
	    temp->detectors[idet++] = atoi(str);
	    i +=2;
	 }
      }

      *detList = temp;
   }

   else   /* call the program recursively for the next node in detList */
   {
      DetInsert(pBase, pLast, mult, detid, detcode, &(*detList)->next);
   }
}
