/* 
-------- Function: -----------------------------------------------------------------------

     DetRanges


-------- Description: --------------------------------------------------------------------

     This function scans the detector id list obtained from the first pointing on the GOOD
     TIME extension and returns detector ranges to be processed.  If detidList contains: 
     0,8,9,...103, the program will return:
        numRanges=2
	Range1: 0..8
	Range2: 0..103

     ASSUMPTION:
        Number of detector ids in a given pointing <= number of rows in the pseudo 
	detector lookup table
	Each pointing in Good Time extension contains same detectors as does the first 
	pointing
        Detector ids are listed in increasing order

-------- Usage: --------------------------------------------------------------------------
 
   void DetRanges(goodTimesPtr pGtimes, detinfoPtr pDet)

   Input Parameters:		 
	      goodTimesPtr pars
	      -----------------
       DETID         long      : Array containing detector ids read from each row of the
                                 GOOD TIME extension

              detinfoPtr pars
              ---------------
       MAXDET        int       : Total number of detectors for the instrument

				  
   Output Parameters:
              detinfoPtr pars
	      ---------------
       NUMRANGES     int       : Number of input detector ranges
       DETRANGE1     int       : Array containing the lower bounds on detectors
       DETRANGE2     int       : Array containing the upper bounds on detectors
       

-------- Include files -------------------------------------------------------------------

   "spihist.h"


-------- Authors/Modification History: ---------------------------------------------------

   Craig Gordon    (3.1.2; Jan 04) ; rewrite in order to fix bug 
                                     which occurred when the first
                                     range consisted of just 1 detector.
   Sandhia Bansal  (1.0.0; Aug 00)


-------------------------------------------------------------------------------------- */

#include "spihist.h"


void DetRanges(goodTimesPtr pGtimes, detinfoPtr pDet)
{
   int i = 0;
   int prevId = 9999;
   int iRanges = 0;
   
   while (i<pDet->maxdet && pGtimes->detid[i] != -1)
   {
      if (pGtimes->detid[i] != prevId + 1)      
      {
         /* start new range */
         pDet->detRange1[iRanges] = pGtimes->detid[i];
         pDet->detRange2[iRanges] = pGtimes->detid[i];
         ++iRanges; 
      }
      else
      {
         /* continuation of existing range */
         pDet->detRange2[iRanges-1] = pGtimes->detid[i];
      }
      prevId = pGtimes->detid[i];
      ++i;
   }
   pDet->numRanges = iRanges;
}
