/* 
-------- Function: -----------------------------------------------------------------------

     DitherListDelete


-------- Description: --------------------------------------------------------------------

     This program deletes the linked list recursively pointed to by the input node.


-------- Functions called: ---------------------------------------------------------------

   SPI  Functions:
      FreeNode      -- Frees some of the allocated memory when not needed


-------- Usage: --------------------------------------------------------------------------

   void DitherListDelete(ditherPtr dlist, memoryPtr *pBase, memoryPtr *pLast)

   Input Parameters:
       DLIST         ditherPtr    : Each node in this list corresponds to a single dither
                                    single dither node
       PBASE         memoryPtr    : Pointer to the list that keeps track of allocated
                                    memory
       PLAST         memoryPtr    : Pointer to the current node in the list pointed to by
                                    PBASE

   Output Parameters:
       DLIST         ditherPtr    : Empty list


-------- Include files -------------------------------------------------------------------

   "spihist.h"


-------- Authors/Modification History: ---------------------------------------------------

   Sandhia Bansal  (1.0.0; May 98)

--------------------------------------------------------------------------------------- */


#include "spihist.h"



void DitherListDelete(ditherPtr dlist, memoryPtr *pBase, memoryPtr *pLast)
{
   ditherPtr old=NULL;


   if (dlist != NULL)
   {
      FreeNode(pBase, (void **) &(dlist->raDec), pLast);
      old   = dlist;

      dlist = dlist->next;
      FreeNode(pBase, (void **) &old, pLast);

      DitherListDelete(dlist, pBase, pLast);
   }
}
