/* 
-------- Function: -----------------------------------------------------------------------

     EchoSpihistInput


-------- Description: --------------------------------------------------------------------

     This program echoes the SPIHIST input parameters to the screen.


-------- Functions called: ---------------------------------------------------------------

   RIL Functions:
      RILlogMessage       -- Writes input message to screen and log file


-------- Usage: --------------------------------------------------------------------------

   void EchoSpihistInput(char *detnums, outputParsPtr pOutput, 
			 eventCriteriaPtr pEventCriteria, headerParsPtr pHeader)
			
   Input Parameters:
       DETNUMS       char      : Ids of detectors to be processed (allowed characters in
                                 the string are digits, '-', and ','

		outputParsPtr pars
		------------------
       FORMAT        char      : Format for the output file
       DTYPE         int       : Output data format (counts=1, rates=2)
       CHATTER       int       : Chattiness flag for o/p (5 quite,10 normal, >20 silly)
       CLOBBER       int       : 1=Overwrite existing output file, if any
                                 0=Prompt user before overwriting existing output file

                eventCriteriaPtr pars
		---------------------
       TSTART        char      : Start time for data accumulations
       TSTOP         char      : Stop time for data accumulation

                headerParsPtr pars
		------------------
       INSTRUME      char      : String listing instrument/detector


-------- Include files -------------------------------------------------------------------

   "spihist.h"


-------- Authors/Modification History: ---------------------------------------------------

   Craig Gordon   (2.2.1; Nov 02) Removed tstart and tstop parameters.
   Sandhia Bansal  (1.0.1; Nov 00)  Minor changes to create message string.
   Sandhia Bansal  (1.0.0; Aug 00)

--------------------------------------------------------------------------------------- */

#include "spihist.h"



void EchoSpihistInput(char *detnums, outputParsPtr pOutput, 
		      eventCriteriaPtr pEventcriteria, headerParsPtr pHeader)
{
   char message[DAL_MAX_STRING];
   char *program="EchoSpihistInput";


   sprintf(message, "format: %s", pOutput->format);
   RILlogMessage(NULL, Log_1, message);	

   if (strcmp(pOutput->format, "PHA") == 0) 
   {
      sprintf(message, "detnums: %s", detnums);
      RILlogMessage(NULL, Log_1, message);	

      sprintf(message, "dtype: %d", pOutput->dtype);
      RILlogMessage(NULL, Log_1, message);	

      sprintf(message, "output file name: %s", pOutput->fname);
      RILlogMessage(NULL, Log_1, message);	
   }

   sprintf(message, "instrument: %s", pHeader->instrume);
   RILlogMessage(NULL, Log_1, message);	

   sprintf(message, "clobber: %d", pOutput->clobber);
   RILlogMessage(NULL, Log_1, message);	

   sprintf(message, "chatter: %d", pOutput->chatter);
   RILlogMessage(NULL, Log_1, message);	

   strcpy(message, " ");
   RILlogMessage(NULL, Log_1, message);	
}
