/* 
-------- Function: -----------------------------------------------------------------------

     GetDitherArray


-------- Description: --------------------------------------------------------------------

     This program transfers the Pointing information from the input linked list to arrays
     so that they can be used with CFITSIO.

-------- Functions called: ---------------------------------------------------------------

   SPI Functions:
      Allocate        --  Allocates specified number of bytes and keeps track of all
                          allocated memory during a run


-------- Usage: --------------------------------------------------------------------------

   void GetditherArray(memoryPtr *pBase, memoryPtr *pLast, ditherPtr ditherList,
                       int count, double **startTime, double **obsTime, double **xRa, 
		       double **xDec, double **yRa, double **yDec, double **zRa, 
		       double **zDec)

   Input Parameters:
       PBASE                          memoryPtr : Pointer to the list that keeps track of
                                                  allocated memory
       PLAST                          memoryPtr : Pointer to the current node in the list
                                                  pointed to by PBASE
       DITHERLIST                     ditherPtr : Linked list containing the x/y/z ra and
                                                  dec values
       COUNT                          int       : Number of nodes in DITHERLIST
                                         

   Output Parameters:
       STARTTIME                      double    : Array of pointing start times
       OBSTIME                        double    : Array of pointing observed times
       XRA,XDEC, YRA,YDEC, ZRA,ZDEC   double    : x,z-ra/dec in degrees


-------- Include files -------------------------------------------------------------------

   "spihist.h"


-------- Authors/Modification History: ---------------------------------------------------

   Sandhia Bansal  (1.0.0; Aug 00)


--------------------------------------------------------------------------------------- */

#include "spihist.h"


void GetditherArray(memoryPtr *pBase, memoryPtr *pLast, ditherPtr ditherList, int count, 
		    double **startTime, double **obsTime, double **xRa, double **xDec,
		    double **yRa, double **yDec, double **zRa, double **zDec)
{
   ditherPtr  curr=NULL;

   int        i=0;

   char       *program="GetDitherArray";



   /* The following memory is freed in CreatePointingExt */
   Allocate(program, "-startTime", 0, count*sizeof(double), (void **) &(*startTime), pBase,
	    pLast);
   Allocate(program, "-obsTime", 0, count*sizeof(double), (void **) &(*obsTime), pBase,
	    pLast);
   Allocate(program, "-xRa", 0, count*sizeof(double), (void **) &(*xRa), pBase, pLast);
   Allocate(program, "-xDec", 0, count*sizeof(double), (void **) &(*xDec), pBase, pLast);
   Allocate(program, "-yRa", 0, count*sizeof(double), (void **) &(*yRa), pBase, pLast);
   Allocate(program, "-yDec", 0, count*sizeof(double), (void **) &(*yDec), pBase, pLast);
   Allocate(program, "-zRa", 0, count*sizeof(double), (void **) &(*zRa), pBase, pLast);
   Allocate(program, "-zDec", 0, count*sizeof(double), (void **) &(*zDec), pBase, pLast);

   i = 0;
   for (curr=ditherList; curr!=NULL; curr=curr->next)
   {
      (*startTime)[i] = curr->startTime;
      (*obsTime)[i]   = curr->obsTime;
      (*xRa)[i]       = curr->raDec[0];
      (*xDec)[i]      = curr->raDec[1];
      (*yRa)[i]       = curr->raDec[2];
      (*yDec)[i]      = curr->raDec[3];
      (*zRa)[i]       = curr->raDec[4];
      (*zDec)[i]      = curr->raDec[5];
      
      i++;
   } 
}






