/* 
-------- Function: -----------------------------------------------------------------------

     GetRange


-------- Description: --------------------------------------------------------------------

     This subroutine parses the detector list to generate the ranges of detectors to be 
     processed.  This function is only called for PHA output option.


-------- Functions called: ---------------------------------------------------------------

   SPIHIST Functions:
      ParseNumString      -- Parses the input string to generate ranges


-------- Usage: --------------------------------------------------------------------------

   void GetRange(memoryPtr *pBase, memoryPtr *pLast, detinfoPtr detPtr,
			int *detSumFlag, int *pntSumFlag)

   Input Parameters:
       PBASE         memoryPtr  : Pointer to the list that keeps track of allocated
                                  memory
       PLAST         memoryPtr  : Pointer to the last node in the list pointed to by PBASE

              detinfoPtr pars
              ---------------
       MAXDET        int        : Total number of detectors for the instrument
       DETNUMS       char       : Input string of characters specifying detector ids to be
                                  processed	

   Output Parameters:
              detinfoPtr pars
              ---------------
       NUMRANGES     int        : Number of ranges derived from ROWS
       DETRANGE1     int        : Array containing the lower bounds on ranges
       DETRANGE2     int        : Array containing the upper bounds on ranges

       DETSUMFLAG	int	: Set to -1 if "-" was specified
       PNTSUMFLAG

-------- Include files -------------------------------------------------------------------

   "spihist.h"


-------- Authors/Modification History: ---------------------------------------------------
                  
		  (3.0.2; Feb 03)  Disallow "-" entry for dets
   Craig Gordon   (2.2.0; Aug 02)  Using new parser function
   Sandhia Bansal  (1.0.0; Aug 00)

--------------------------------------------------------------------------------------- */

#include "spihist.h"


void GetRange(memoryPtr *pBase, memoryPtr *pLast, detinfoPtr detPtr, 
		int *detSumFlag, int *pntSumFlag)
{
   char  *program="GetRange";
   char  message[DAL_MAX_STRING];

   /* Validate the input string */
   if (ParseNumString(detPtr->detnums, detPtr->detRange1, detPtr->detRange2,
   			&detPtr->numRanges) == ISDC_OK)
   {
      if (detPtr->detRange1[0] == -1 && detPtr->detRange2[0] == -1)
      {
         /* detnums string = "-" */
	 /* Not currently supporting this feature as of - v3.0.2 */
	/* *detSumFlag = *pntSumFlag = -1;
	 detPtr->detRange1[0] = 0;
	 detPtr->detRange2[0] = detPtr->maxdet-1;
	*/
	 strcpy(message, "Invalid Detector Input");
	 Cleanup(SPI_INVALID_PARAMETER, message, *pBase, program);
      }
      else if (detPtr->detRange1[0] == -1)
      {
         detPtr->detRange1[0] = 0;
      }
      else if (detPtr->detRange2[detPtr->numRanges-1] == -1)
      {
         detPtr->detRange2[detPtr->numRanges-1] = detPtr->maxdet-1;
      }
   }

   else 
   {
      strcpy(message, "Invalid Detector Input");
      Cleanup(SPI_INVALID_PARAMETER, message, *pBase, program);
   }
}



