/*----------- Function -------------------------------------------------

      Hsort
      
------------- Description ----------------------------------------------

   Routine to perform a heapsort on the gti times of all the detectors of a
   particular SWG. (Based on heapsort in Weiss, "Data Structures and Algorithm
   Analysis in C++", 1994, p262)    This is used due to a flaw found in the
   Solaris compiler's standard lib qsort routine.  That routine takes O(N^2) to
   sort an array consisting of mostly identical elements, which is what most of
   the gti extensions are likely to contain.  This should take O(N) to sort a
   file of mostly identical elements and O(NlogN)  otherwise.
   
------------------------------------------------------------------------
   
   Input Parameters:
      ARRAY	gtIntPtr*	:Pointer to an array of pointers to 
      				 GTINT structs.  
      SZ	int		:Number of elements in ARRAY to be sorted.
      				 NOTE:  ARRAY is 1-BASED.  Array[0] is
				 merely a sentinel placeholder not
				 used by Hsort.  Therefore SZ is 1 less
				 than the true size of ARRAY.
   
   
------------- Authors/Modification History: ----------------------------

   Craig Gordon   (2.1.9; Jul 02)
   
------------------------------------------------------------------------
*/  
 
#include "spihist.h"

/* PercDown - a helper function only to be used by Hsort */
static void PercDown(gtIntPtr *array, int i, int sz);

void Hsort(gtIntPtr *array, int sz)
{
   int i;
   gtIntPtr tmp;
   
   for (i=sz/2; i>0; i--)
   {
      PercDown(array, i, sz);
   }
   for (i=sz; i>=2; i--)
   {
      tmp = array[1];
      array[1] = array[i];
      array[i] = tmp;
      
      PercDown(array, 1, i-1);  
   }
}

void PercDown(gtIntPtr *array, int i, int sz)
{
   int child;
   gtIntPtr tmp;
   
   tmp = array[i];
   while (i*2 <= sz)
   {
      child = i*2;
      if (child != sz && array[child+1]->obStart > array[child]->obStart)  ++child;
      if (tmp->obStart < array[child]->obStart)
      {
         array[i] = array[child];
      }
      else
         break;
      i = child;
   }
   array[i] = tmp;
} 
