/*----------- Function -------------------------------------------------

   IsSingleOrPsd
   
------------- Description ----------------------------------------------

   Determines whether a detector falls within 0-18 or 85-103 range.
   Also outputs a corresponding index from 0-37 for use in accessing
   OB information in detinfoStruct.
   
------------------------------------------------------------------------
   
   Input Parameters:
      DETNUM		int		: pseudo detector number
   
   Output Parameters:
      INDEX		int		: 0-18 -> 0-18, 85-103 -> 19-37
      					  = -1 if not in range
   
   Return Value:
      0 if not within the single or psd range
      1 if it is
   
------------- Authors/Modification History: ----------------------------

   Craig Gordon   (3.0.0; Dec 02)
   
------------------------------------------------------------------------
*/   
#include "spihist.h"

int IsSingleOrPsd(int detnum, int *index)
{
   int i, inRange;
   extern const int gl_boundaries[2][6];
   extern const int gl_numbnds;
   
   inRange = 0;
   *index = -1;
   if (detnum < gl_boundaries[0][0])
   {
      *index = detnum;
      inRange = 1;
   }
   else if (detnum >= gl_boundaries[0][2] && detnum < gl_boundaries[0][3])
   {
      *index = detnum - gl_boundaries[0][2] + gl_boundaries[0][0];
      inRange = 1;
   }   
   return inRange;
}
