/* 
-------- Function: -----------------------------------------------------------------------

     ListDither


-------- Description: --------------------------------------------------------------------

     This program creates a new linked list (or a new node in the list if it already
     exists) and copies the Pointing info (x/y/z ra and dec) to the node.


-------- Functions called: ---------------------------------------------------------------

   SPI Functions:
      Allocate              -- Allocates specified number of bytes and keeps track of all
                               allocated memory during a run


-------- Usage: --------------------------------------------------------------------------

   int ListDither(memoryPtr *pBase, memoryPtr *pLast, double startTime, double obsTime, 
                  double *raDec, DITHERNODE **ditherList)

   Input Parameters:
       PBASE         memoryPtr    : Pointer to the list that keeps track of allocated
                                    memory
       PLAST         memoryPtr    : Pointer to the current node in the list pointed to by
                                    PBASE
       STARTTIME     double       : Start time of the current pointing
       OBSTIME       double       : Observed time of the current pointing
       RADEC         double       : Array containing x/y/z RA and DEC values.


   Output Parameters:
       DITHERLIST    ditherPtr    : Linked list containing the X/Y/Z RA, DEC and number of
                                    histograms for each accumulated pointing.


-------- Include files -------------------------------------------------------------------

   "spihist.h"


-------- Authors/Modification History: ---------------------------------------------------

   Sandhia Bansal  (1.0.0; Aug 00)

--------------------------------------------------------------------------------------- */

#include "spihist.h"


int ListDither(memoryPtr *pBase, memoryPtr *pLast, double startTime, double obsTime, 
	       double *raDec, DITHERNODE **ditherList)
{
   static DITHERNODE  *prev=NULL;
   DITHERNODE         *curr=NULL;
   DITHERNODE         *newnode=NULL;

   static int count=0;
   int        i=0;

   char       *program="ListDither";
   char       message[DAL_MAX_STRING];
   char       **temp=NULL;


   for (curr=*ditherList; curr!=NULL; curr=curr->next)
      prev = curr;

   Allocate(program, "-newnode", 0, sizeof(DITHERNODE), (void **) &newnode, pBase, pLast);
   newnode->raDec = NULL;
   newnode->next = NULL;

   count++;

   newnode->startTime = startTime;
   newnode->obsTime   = obsTime;

   Allocate(program, "-newnode->raDec", 0, NRADEC*sizeof(double), 
	    (void **) &(newnode->raDec), pBase, pLast);
   for (i=0; i<NRADEC; i++)
      newnode->raDec[i] = raDec[i];

   newnode->next    = NULL;

   if (prev == NULL)
      *ditherList = newnode;
   else
      prev->next = newnode;

   return(count);
}



