/* 
-------- Function: -------------------------------------------------------------

     Multiplicity


-------- Description: ----------------------------------------------------------

     This program returns the multiplicity of a given detector based on its
     code read from the pseudo detector lookup table.


--------- Usage: ---------------------------------------------------------------

   int Multiplicity(char *detcode)

   Input Parameters:
       DETCODE       string       : String consisting of real detector ids

   Output Parameters:
       -             int          : Multiplicity of the current detector
                                    Returns -1 if DETCODE is invalid


-------- Include files ---------------------------------------------------------

   "spihist.h"


-------- Authors/Modification History: -----------------------------------------

   Sandhia Bansal  (1.0.0; Aug 00)

----------------------------------------------------------------------------- */

#include "spihist.h"


int Multiplicity(char *detcode)
{
   int   len=0;

   char  tmp1[2];


   len = strlen(detcode);

   if ((len <= 2) ||
       ((len == 4) && 
	((detcode[1] == '0') || (detcode[1] == '1'))))
   {
      return(0);   /*  detectors are PSD+SINGLES (0-18) or 
		       PSD (1000-1018 or 1100-1118) */
   }

   else if ((len == 4) && (detcode[1] == '9'))
   {
     return(1);   /* detectors are 1900-1918 (Real) */
   }

   else if (len >= 5)   /* detector multiplicity is 2 or higher */
   {
      tmp1[0] = detcode[0];
      tmp1[1] = '\0';
      return(atoi(tmp1));
   }

   else
   {
      return(-1);
   }
}
