/* 
-------- Function: -------------------------------------------------------------

     MultiplicityToProcess


-------- Description: ----------------------------------------------------------

     This function scans the ranges of detectors to be processed to determine
     the multiplicity ranges.


-------- Functions called: -----------------------------------------------------

   Spihist Functions:
      Multisearch     --   Helper function searches multiplicity array and adds 
      			   new multiplicity if it is not already there.


-------- Usage: ----------------------------------------------------------------
 
   int MultiplicityToProcess(detinfoPtr pDet, int *nmulti, int *multiplicity)

   Input Parameters:	
              detinfoPtr pars
              ---------------
       NUMRANGES       int      : Number of input detector ranges
       DETRANGE1       int      : Array containing the lower bounds on detectors
       DETRANGE2       int      : Array containing the upper bounds on detectors
       
       PGTROWS	       gtRowsPtr :Good time info, needed as a final check
       				 before adding a multiplicity to the list to
				 be processed.
       IPOINTING	int	:Index of pointing to be processed.
    
				  
   Output Parameters:
       NMULTI          int      : Number of multiplicity to be processed
       MULTIPLICITY    int      : Array containing multiplcities to be processed
       

-------- Include files ---------------------------------------------------------

   "spihist.h"


-------- Authors/Modification History: -----------------------------------------
 
                 (3.0.4; Feb 03) ;Modified GTI test using new gtRows struct.
                 (3.0.1; Jan 03) ;Add valid GTI requirement
 	         (3.0.0; Dec 02) ;Additional mode checks for ob spectra for
		                  dets 0-18 and 85-103
   Craig Gordon  (2.1.2; Sep 01)
   Craig Gordon   (2.1.1; Aug 01)
   Sandhia Bansal  (1.0.0; Aug 00)


----------------------------------------------------------------------------- */

#include "spihist.h"

static void Multisearch(int, int*, int*);

int MultiplicityToProcess(detinfoPtr pDet, gtRowsPtr pGtrows, int iPointing, 
		int *nmulti, int *multiplicity)
{
   int detnum;
   extern const int gl_numbnds;
   extern const int gl_boundaries[2][6];
   extern const short gl_oper;
   int  i, j, idx, found;
   long iGT;
   
   for (i=0; i<pDet->numRanges; ++i)
   {
      for (detnum=pDet->detRange1[i]; detnum<=pDet->detRange2[i]; ++detnum)
      {
         if (detnum < 0 || detnum >= gl_boundaries[0][gl_numbnds-1])
	 {
	    return SPI_INVALID_PSEUDODET;
	 }
	 
	 /* GTI test added 3.0.1, modified 3.0.4 */
	 if (!pGtrows->nInts[iPointing][detnum])
	 {
	    /* No need to go any further for this detector.*/
	    continue;
	 }
	 
         if (IsSingleOrPsd(detnum, &idx))
	 {
	    if (idx < gl_boundaries[0][0]) 
	    {
               /* Check if detector will need single psd events data */
	       if (pDet->spiMode[idx] == gl_oper)
	       {
		  Multisearch(0, nmulti, multiplicity);
		  if (!pDet->obSpectraFlag[idx])
		  { /* no ob spectra for singles, will need these events too */
		     Multisearch(1, nmulti, multiplicity);
		  }
	       }
	    }
	    else  /* dets 85-103, map to index 19-37 */
	    {
	       if (pDet->spiMode[idx] == gl_oper && !pDet->obSpectraFlag[idx])
	       {
		  Multisearch(1, nmulti, multiplicity);
	       }

	    }
	 }
	 else
	 {
	    j=1;
            found = 0;
	    while(!found && j<gl_numbnds)
	    {
	       if (detnum < gl_boundaries[0][j])
	       {
		  found = 1;
	       }
	       else
	       {
		  ++j;
	       }
	    }
            Multisearch(gl_boundaries[1][j], nmulti, multiplicity);
	 }
      }
   }
   
   return (ISDC_OK);
}
 
 
void Multisearch(int mult, int *nummult, int *multarray)
{
   int i=0, found=0;
   while (!found && i<*nummult)
   {
      if (mult == multarray[i++])
         found = 1;
   }
   if (!found)
      multarray[(*nummult)++] = mult;
   return;
}




