/*----------- Function -------------------------------------------------

   OBHist

------------- Description ----------------------------------------------

   Routine to do the actual addition of an OB spectrum into the histogram.
   The histogram may already contain psd events data in dets 0-18, in 
   which case the already existing events count will be proportionally
   modified to correspond to the OB spectrum on-time.
   
------------------------------------------------------------------------
   
   Input Parameters:
      PDET		detinfoPtr	:Detector information including
      					  histogram of counts
      IDET		int		:Physical detector num (0-18)
      RANGE		int		:Pseudodet range, 0 for 0-18
      						          1 for 85-103
      ADDCOUNTS		long *		:Binned OB spectrum to be added
      GTLIST		gtIntPtr **	:GTI information
   
   Output Parameters:
      TOTADDED		long		:total counts actually added to
      					  histogram from spectrum
   Return Value:
   
------------- Authors/Modification History: ----------------------------

   Craig Gordon   (3.0.0;  Dec 02)
   
------------------------------------------------------------------------
*/   
#include "spihist.h"

void OBHist(detinfoPtr pDet, int iDet, int range, long *addCounts, 
		gtIntPtr **gtList, long *totAdded)
{
   int i;
   extern const int gl_boundaries[2][6];
   const int offset = gl_boundaries[0][2]; /* = 85 */
   
   if (range == 0)
   {
      /* Add to detectors 0-18 */
      if (pDet->obEmerFlag)
      {
         /* No psd events to mix with */
	 for (i=0; i<pDet->detchans; ++i)
	 {
	    pDet->hist[iDet][i] += addCounts[i];
	    *totAdded += addCounts[i];
	 }
      }
      else
      {
         /* This will have to be modified to take into account psd vs
	    OB ontime */
	 for (i=0; i<pDet->detchans; ++i)
	 {
	    pDet->hist[iDet][i] += addCounts[i];
	    *totAdded += addCounts[i];
	 }	   
      }
   }
   else
   {
      /* Add to detectors 85-103.  Must be in OPER mode. */
      for (i=0; i<pDet->detchans; ++i)
      {
         pDet->hist[iDet+offset][i] += addCounts[i];
	 *totAdded += addCounts[i];
      }
   }
}
