/* 
-------- Function: -------------------------------------------------------------

     PseudoDet


-------- Description: ----------------------------------------------------------

     This function returns a psuedo detector code associated with the detector
     list of multiplicity n.  This function operates on non-PSD detectors. If
     the search is unsuccessful, the function returns a value of -1.


-------- Functions called: -----------------------------------------------------

   SPIHIST Functions:
      DetLookup         -- Returns the detector number that created ith event 


-------- Usage: ----------------------------------------------------------------

   short PseudoDet(DAL3_Byte *dete, detinfoPtr pDet)

   Input Parameters:
       DETE           DAL3_Byte         : List of detector ids

               detinfoPtr pars
	       ---------------
       MULTIPLICITY   short          : Multiplicity associated with the list 
                                       DETE
       PSEUDODETLIST  pseudoDetPtr   : Pointer to the list containing 
                                       detectors of multiplicity MULTIPLICITY

   Output Parameters:
       DETID          short          : Pseudo detector code associated with DETE


-------- Include files ---------------------------------------------------------

   "spihist.h"


-------- Authors/Modification History: -----------------------------------------

   Sandhia Bansal  (1.0.0; Aug 00)

----------------------------------------------------------------------------- */

#include "spihist.h"


short PseudoDet(DAL3_Byte *dete, detinfoPtr pDet)
{
   int             i=0;

   short           detid=-1;

   char            qFound=0;

   pseudoDetPtr    curr=NULL;


   /* Scan the pseudo detector list for given multiplicity to see if the
      detectors in DETE are defined in the look up table
      If so, return the code associated with DETE detectors */
   for (curr=pDet->pseudoDetList[pDet->multiplicity]; curr!=NULL && 
	  detid==-1; curr=curr->next)
   {
      qFound = 1;

      for (i=0; i<pDet->multiplicity && qFound==1; i++)
	 qFound = DetLookup(pDet->multiplicity, dete[i], curr->detectors);

      if (qFound == 1)
	 detid = curr->pseudoDet;
   }

   return(detid);
}
