/* 
-------- Function: -------------------------------------------------------------

     PseudoDetLookup


-------- Description: ----------------------------------------------------------

     This program operates on the given row of the events data.  It returns the
     detector number that created this event and places the corresponding energy
     in it.


-------- Functions called: -----------------------------------------------------

   Spihist Functions:
      PseudoPSDdet          -- Returns PSD detector that created this event
      PseudoDet             -- Returns non-PSD detector that created this event


-------- Usage: ----------------------------------------------------------------

   void PseudoDetLookup(int irow, eventsInfoPtr pEvents, detinfoPtr pDet)

   Input Parameters:
       IROW          int             : Index to the row read from the event data

              eventsInfoPtr pars
	      ------------------
       DETE          DAL3_Byte       : Detector ids read from the events table
       PSDFLAG       DAL3_Byte       : PSD flags read from the events table
       PI            float           : Energies read from the events table

               detinfoPtr pars
	       ---------------
       MULTIPLICITY  short           : 0: PSD data
                                       1-6 : SINGLE, DOUBLE, TRIPLE, QUADRUPLE,
				       QUINTUPLE, and HI_MULT data repectively
       PSEUDODETLIST pseudoDetPtr    : Array of lists for each multiplicity -
                                       Each node in a list consists of a PSD 
				       flag, pseudo detector number and ids of
				       the detectors that constitute this 
				       pseudo detector number


   Output Parameters:
               detinfoPtr pars
	       ---------------
       DET0          short           : Id of the selected detector
       DET1          short           : Id of the selected detector (PSD only)
       PI0           float           : Energy of the selected detector


-------- Include files ---------------------------------------------------------

   "spihist.h"


-------- Authors/Modification History: -----------------------------------------

   Craig Gordon  (2.1.1; Aug 01)
   Sandhia Bansal  (1.0.0; Aug 00)


----------------------------------------------------------------------------- */

#include "spihist.h"


void PseudoDetLookup(int irow, eventsInfoPtr pEvents, detinfoPtr pDet)
{
   int         idet=0, i=0;

   DAL3_Byte   dete[NEVENTTYPE];



   pDet->det0 = -1;
   pDet->pi0  = 0.0;

   /*printf("multiplicity:%d\n", pDet->multiplicity);*/
   if (pDet->multiplicity == 0)   /* PSD events - always SINGLEs */
   {
      pDet->det0 = PseudoPSDdet(pEvents->dete[irow], pEvents->psdFlag[irow],
				pDet->pseudoDetList[pDet->multiplicity]);
      pDet->pi0  = pEvents->pi[irow];
      
   }

   else if (pDet->multiplicity == 1)  /* Single - non-PSD events */
   {
      dete[0]  = pEvents->dete[irow];
      pDet->pi0   = pEvents->pi[irow];
      pDet->det0 = PseudoDet(dete,pDet);
   }

   else   /* DOUBLE, TRIPLE, QUADRUPLE, QUINTUPLE, HI_MULT events */
   {
      idet = irow * pDet->multiplicity;
      for (i=0; i<pDet->multiplicity; i++)
      {
	 dete[i]      = pEvents->dete[idet];
	 pDet->pi0 += pEvents->pi[idet++];
      }

      pDet->det0 = PseudoDet(dete, pDet);
   }
}
