/* 
-------- Function: -------------------------------------------------------------

    PseudoPSDdet


-------- Description: ----------------------------------------------------------

     The program searches the detector list for specified detector with given
     psd flag.  If found, it returns the pseudo detector number associated with
     this detector.


-------- Functions called: -----------------------------------------------------

   SPIHIST Functions:
      PSDlookup          --  Returns true if it finds the detector in the list


-------- Usage: ----------------------------------------------------------------

   short PseudoPSDdet(DAL3_Byte dete, DAL3_Byte psdFlag, pseudoDetPtr detList)

   Input Parameters:
       DETE          DAL3_Byte       : Detector id to be searched for
       PSDFLAG       DAL3_Byte       : PSD flag associated with detector DETE
       DETLIST       pseudoDetPtr    : Pointer to the list containing available
                                       PSD detectors


   Output Parameters:
       DETID         short           : Pseudo detector number associated with
                                       DETE: If found
                                       -1: Otherwise


-------- Include files ---------------------------------------------------------

   "spihist.h"


-------- Authors/Modification History: -----------------------------------------

   Sandhia Bansal  (1.0.0; Aug 00)


----------------------------------------------------------------------------- */

#include "spihist.h"


short PseudoPSDdet(DAL3_Byte dete, DAL3_Byte psdFlag, pseudoDetPtr detList)
{
   short          detid=-1;

   pseudoDetPtr   curr=NULL;


   /* Scan the pseudo detector list for PSD detector to see if the
      detector DETE is defined in the look up table
      If so, return the code associated with DETE detector */
   for (curr=detList; curr!=NULL && detid==-1; curr=curr->next)
   {
      if (PSDlookup(dete, psdFlag, curr) == 1)
         detid = curr->pseudoDet;
   }

   return(detid);
}
