/* 
-------- Function: -------------------------------------------------------------

     PutHduclas2

-------- Description: ----------------------------------------------------------

     This subroutine writes the HDUCLAS2 keyword to the DATA, EBOUNDS and
     POINTING extensions of the PHA II file created by SPIHIST.


-------- Functions called: -----------------------------------------------------

   SPI  Functions:
      PutKeyword            -- Writes the specified keyword to the table header


-------- Usage: ----------------------------------------------------------------

   void PutHduclas2(dal_element *objectPtr, headerParsPtr pHeader)

   Input Parameters:
       OBJECTPTR    dal_element   : Pointer to the current element

                headerParsPtr pars
		------------------
       HDUCLAS2     char          : String containing HDUCLAS2 value


-------- Include files ---------------------------------------------------------

   "spihist.h"


-------- Authors/Modification History: -----------------------------------------

   Sandhia Bansal  (1.0.0; Mar 99)


----------------------------------------------------------------------------- */

#include "spihist.h"


void PutHduclas2(dal_element *objectPtr, headerParsPtr pHeader)
{
   char  comment[DAL_MAX_ATT_COMMENT_SIZE]="\0";
   char  *program="PutHduclas2";


   if (strcmp(pHeader->hduclas2, "TOTAL") == 0)	 
      strcpy(comment, "Gross PHA Spectrum (source + bkgd)");

   else if (strcmp(pHeader->hduclas2, "NET") == 0)
      strcpy(comment, "Bkgd-subtracted PHA Spectrum");

   else if (strcmp(pHeader->hduclas2, "BKG") == 0)
      strcpy(comment, "Bkgd PHA Spectrum");

   else if (strcmp(pHeader->hduclas2, "UNKNOWN") == 0)
      strcpy(comment, "Maybe TOTAL, NET or BKG Spectrum");

   else
      strcpy(comment, "WARNING: This is NOT an OGIP-approved value");

   PutKeyword(objectPtr, "HDUCLAS2", pHeader->hduclas2, CHAR, comment, program);
}
