/*----------- Function -------------------------------------------------

   ReportOutputType 
   
------------- Description ----------------------------------------------

   Reports what type of data will be added to pseudodetectors 0-18, 85-103
   
------------------------------------------------------------------------
   
   Input Parameters:
      PDET			detinfoPtr	:Contains output type info
      POUTPUT			outputParsPtr	:chatter level
      
------------- Authors/Modification History: ----------------------------

   Craig Gordon   (3.0.0; Dec 02)
   
------------------------------------------------------------------------
*/   

#include "spihist.h"

void ReportOutputType(detinfoPtr pDet, outputParsPtr pOutput)
{
   int i=0, det1, det2, idx, obflag, status=ISDC_OK;
   extern const int gl_boundaries[2][6];
   extern const short gl_oper, gl_emer;
   char *program = "ReportOutputType";
   char message[DAL_MAX_STRING];
   char type1[14], type2[14];
   const char *types[]={"Singles", "Singles + PSD", "OB/Oper", 
   			"OB/Emer", "OB/Oper + PSD", "none"};
   
   strcpy(message, "Type of output in pseudodetectors 0-18, 85-103");
   DispMsg(Log_1, message, status, program, pOutput->chatter);
   
   for (i=0; i<SPISTRUCT_NDETS; ++i)
   {
      det1 = i;
      det2 = gl_boundaries[0][2] + i;
      
      /* For 0-18 */
      obflag = pDet->obSpectraFlag[i];
      if (pDet->spiMode[i] == gl_oper)
      {
         if (obflag)
	 {
	    strcpy(type1, types[4]);
	 }
	 else
	 {
	    strcpy(type1, types[1]);
	 }
      }
      else if (pDet->spiMode[i] == gl_emer)
      {
         strcpy(type1, types[3]);
      }
      else
      {
         strcpy(type1, types[5]);
      }
      
      /* For 85-103 */
      idx = i + gl_boundaries[0][0];
      obflag = pDet->obSpectraFlag[idx];
      if (pDet->spiMode[idx] == gl_oper)
      {
         if (obflag)
	 {
	    strcpy(type2, types[2]);
	 }
	 else
	 {
	    strcpy(type2, types[0]);
	 }
      }
      else
      {
         strcpy(type2, types[5]);
      }
      sprintf(message,"%2d:%16s%20d:%16s",det1, type1, det2, type2);
      DispMsg(Log_1, message, status, program, pOutput->chatter);
   }
   strcpy(message," ");
   DispMsg(Log_1, message, status, program, pOutput->chatter);
}
