/* 
-------- Function: -------------------------------------------------------------

     SetDetFlags


-------- Description: ----------------------------------------------------------

     This function sets flags for detectors that need to be processed.


-------- Usage: ----------------------------------------------------------------
 
   void SetDetFlags(detinfoPtr pDet)

   Input Parameters:		 
              detinfoPtr pars
              ---------------
       MAXDET        int       : Total number of detectors for the instrument
       NUMRANGES     int       : Number of input detector ranges
       DETRANGE1     int       : Array containing the lower bounds on detectors
       DETRANGE2     int       : Array containing the upper bounds on detectors
       NDETROWS      int       : Number of rows in the pseudo detector lookup 
                                 table

				  
   Output Parameters:
              detinfoPtr pars
	      ---------------
       DET           int       : Det[i]=1 if ith detector is requested to be
                                 processed; Valid values are 0 and 1.
       DETRANGE2     int       : Array containing the upper bounds on detectors
       

-------- Include files ---------------------------------------------------------

   "spihist.h"


-------- Authors/Modification History: -----------------------------------------

   Sandhia Bansal  (1.0.0; Aug 00)


----------------------------------------------------------------------------- */

#include "spihist.h"


void SetDetFlags(detinfoPtr pDet)
{
   int  i=0, j=0;



   /* set the detectors which need to be processed to 1 
      set det[0] = 1 when rows=S,<det numbers> */
   for (i=0; i<pDet->maxdet; i++)
      pDet->det[i] = 0;

   for (i=0; i<pDet->numRanges; i++)
   {
      for (j=pDet->detRange1[i]; j<=pDet->detRange2[i]; j++)
	 pDet->det[j] = 1;

      if (pDet->detRange2[i] == pDet->nDetRows)
	 pDet->detRange2[i]--;
   }
}
