/* 
-------- Function: -------------------------------------------------------------

     SpecKeywords


-------- Description: ----------------------------------------------------------

     This function calls CopyKeywords to copy some of the keywords from input
     dal element to the output element.  Then it performs additional copy of the
     TSTART and TSTOP keywords.


-------- Functions called: -----------------------------------------------------

   Spihist Functions:
      CopyKeywords           -- Copies some keywords from the input element to
                                the output

   SPI Functions:
      Cleanup                -- Deallocates all memory allocated during the 
                                current run in the event of an error

   DAL3 Functions:
      DAL3GENattributeCopy   -- Copies keyword from input object to output


-------- Usage: ----------------------------------------------------------------

   void SpecKeywords(dal_element *inputDS, dal_element *pTable, memoryPtr pBase)

   Input Parameters:
       INPUTDS       dal_element   : Pointer to the Observation group DOL
       PTABLE        dal_element   : Pointer to the output dal element
       PBASE         memoryPtr     : Pointer to the list that keeps track of
                                     allocated memory


-------- Include files ---------------------------------------------------------

   "spihist.h"


-------- Authors/Modification History: -----------------------------------------

   Sandhia Bansal  (1.0.0; Jul 00)


----------------------------------------------------------------------------- */

#include "spihist.h"



void SpecKeywords(dal_element *inputDS, dal_element *pTable, memoryPtr pBase)
{
   int   status=ISDC_OK;

   char  message[DAL_BIG_STRING];
   char  *program="SpecKeywords";
   char  attributeName[DAL_MAX_ATTRIBUTE_SIZE];



   /* Copy TIMESYS, TIMEUNIT, MJDREF, CLOCKAPP, TIMEREF, and TASSIGN to the
      output extension */
   CopyKeywords(inputDS, pTable, pBase);

   /* Copy TSTART and TSTOP */
   strcpy(attributeName, "TSTART");
   status = DAL3GENattributeCopy(inputDS, pTable, attributeName, status);

   strcpy(attributeName, "TSTOP");
   status = DAL3GENattributeCopy(inputDS, pTable, attributeName, status);
   
   if (status != ISDC_OK)
   {
      strcat(strcpy(message, "Error while copying "), attributeName);
      Cleanup(status, message, pBase, program);
   }
}
