/* spihist.h 
   header file for SPIHIST */

#ifndef SPIHIST_INCLUDED
#define SPIHIST_INCLUDED


/* Definition of include statements */
#include "spi.h"

#ifdef  __cplusplus
extern "C" {
#endif


/* Definition of constant values */
#define DATA_CHILD              0   /* first extension in the output file */
#define POINTING_CHILD           1   /* second extension in the output file */
#define EBOUNDS_CHILD          2   /* third extension in the output file */
#define MAX_ELEMENTS           10   /* for DAL library routines */
#define PHAVERSN          "1.1.0"
#define ROWIDSZ                20
#define _PI           3.141592654
#define DEGTORAD        _PI/180.0
#define RADTODEG        180.0/_PI
#define BADGT  18446744072635809792
/* For use in reading spi_gain calib tables */
#define SPIHIST_NCOEFF		5
#define SPIHIST_NCHANS		16384
/* Number of detectors in standard det table */
#define SPIHIST_NSTND 142

typedef unsigned char byte;

typedef struct gtint
{
   OBTime obStart;
   OBTime obStop;
} GTINT;
typedef GTINT *gtIntPtr;

typedef struct gtrows
{
   double **livetime;
   int **nInts;
   char **pointingId;
   long nRows;
   int total;
} GTROWS;
typedef GTROWS *gtRowsPtr;

typedef struct obSpectrum
{
   unsigned char det_id;
   unsigned char e_range;
   short counts[SPIHIST_NCHANS];
   OBTime obt_start;
   OBTime obt_end;   
} OBSPECTRUM;
typedef OBSPECTRUM *obSpectrumPtr;

/* Definitions of function prototypes */
int c_fccmpr2(char *rows);

int AddObSpectra(dal_element *og, char *coeffDOL, binningPtr pBin, int pointingNum,
			detinfoPtr pDet, outputParsPtr pOutput, 
			pointingInfoPtr pDither, gtIntPtr **gtList);
			
int CheckParams(outputParsPtr pOutput, eventCriteriaPtr pEventcriteria);

int ColNameToIndex(dal_element *pTable, char *colName);

void CopyEboundsExt(dal_element *inputDS, dal_element *parent, headerParsPtr
		pHeader, memoryPtr *pBase, int chatter);
		
void CopyKeywords(dal_element *inputDS, dal_element *pTable, memoryPtr pBase);

void CopyPointingExt(dal_element *inputDS, dal_element *parent, 
		headerParsPtr pHeader, memoryPtr *pBase, int chatter);

void CopyRaDec(int pointingNum, pointingInfoPtr pDither);

void CreateDataIIExt(dal_element *pTable, memoryPtr *pBase, memoryPtr *pLast, 
		     int pointingNum, char *detnam, gtIntPtr **gtList,
		     gtRowsPtr pGtrows, outputParsPtr pOutput, binningPtr pBin, 
		     detinfoPtr pDet, headerParsPtr pHeader, int detSumFlag, 
		     int pntSumFlag, int totPointings, int lastFlag);

int CreateEventType(short multiplicity, int *eventType);

void CreatePHA_II(dal_element *inputDS, dal_accessType access, memoryPtr *pBase, memoryPtr *pLast, 
		  int pointingNum, int dcount, ditherPtr ditherList, 
		  gtIntPtr **gtList, gtRowsPtr pGtrows, outputParsPtr pOutput, 
		  binningPtr pBin, detinfoPtr pDet, headerParsPtr pHeader, 
		  int detSumFlag, int pntSumFlag, int totPointings);

void DataExtension(dal_element *inputDS, memoryPtr *pBase, memoryPtr *pLast,
		   int chatter, detinfoPtr pDet, headerParsPtr pHeader);

void DeleteColumn(memoryPtr *pBase, dal_element *pTable, char *colName);

void DetInsert(memoryPtr *pBase, memoryPtr *pLast, int mult, int detid, 
	       char *detcode, pseudoDetPtr *detList);

char DetLookup(int mult, DAL3_Byte detid, DAL3_Byte *detectors);

void DetRanges(goodTimesPtr pGtimes, detinfoPtr pDet);

void DitherListDelete(ditherPtr dlist, memoryPtr *pBase, memoryPtr *pLast);

void EchoSpihistInput(char *detnums, outputParsPtr pOutput, 
		      eventCriteriaPtr pEventcriteria, headerParsPtr Peader);

void GetditherArray(memoryPtr *pBase, memoryPtr *pLast, ditherPtr ditherList, 
		    int count, double **startTime, double **obsTime,
		    double **xRa, double **xDec, double **yRa, double **yDec, 
		    double **zRa, double **zDec);

int GetGTForSCW(memoryPtr *pBase, memoryPtr *pLast, gtIntPtr **gtList, 
		gtRowsPtr pGtrows, int iScw, detinfoPtr pDet, 
		OBTime **obgtStart, OBTime **obgtStop);
		 
int GetObSpectra(dal_element *swg, detinfoPtr pDet, obSpectrumPtr **pSpectra, 
			long *nSpectra, outputParsPtr pOutput);

void GetRange(memoryPtr *pBase, memoryPtr *pLast, detinfoPtr detPtr,
		int *detSumFlag, int *pntSumFlag);

void GetValidGT(dal_element *inputDS, memoryPtr *pBase, memoryPtr *pLast, 
		OBTime *obStart, OBTime *obStop, long *detid, 
		goodTimesPtr pGtimes, char **pointingId, long maxnGTI, 
		gtIntPtr **gtList, gtRowsPtr pGtrows);
		  
void Hsort(gtIntPtr *array, int sz);		  

int IndexToChnl(float item, int nItem, float range[]);

void InitDetSpiModes(detinfoPtr pDet, int readOBFlag);

void InitGoodTimesStr(goodTimesPtr pGtimes);

void InitializeHist(int nEnergy, detinfoPtr pDet);

void InitPointingStr(pointingInfoPtr pDither);

int IsSingleOrPsd(int detnum, int *index);

int ListDither(memoryPtr *pBase, memoryPtr *pLast, double startTime, 
	       double obsTime, double *raDec, DITHERNODE **ditherList);

void Livetime(dal_element *inputDS, memoryPtr *pBase, memoryPtr *pLast, 
	      double **livetime);

int Multiplicity(char *detcode);

int MultiplicityToProcess(detinfoPtr pDet, gtRowsPtr pGtrows, int iPointing, 
		int *nmulti, int *multiplicity);

void OBHist(detinfoPtr pDet, int iDet, int range, long *addCounts, 
		gtIntPtr **gtList, long *totAdded);
		
int ParseNumString(char *input, int *rangeLow, int *rangeHigh, int *numRanges);

void ProcessData(int pointingNum, binningPtr pBin, detinfoPtr pDet,
		  eventsInfoPtr pEvents, gtIntPtr **gtList, 
		  gtRowsPtr pGtrows, int *evCount);
		 
void ProgVer(char *taskname, char *version);

char PSDlookup(DAL3_Byte dete, DAL3_Byte psdFlag, pseudoDetPtr detList);

short PseudoDet(DAL3_Byte *dete, detinfoPtr pDet);

void PseudoDetLookup(int irow, eventsInfoPtr pEvents, detinfoPtr pDet);

short PseudoPSDdet(DAL3_Byte dete, DAL3_Byte psdFlag, pseudoDetPtr detList);

void PutHduclas2(dal_element *objectPtr, headerParsPtr pHeader);

int ReadBinFile(dal_element *inputDS, memoryPtr *pBase, memoryPtr *pLast, 
		char *chantype, binningPtr pBin);

void ReadDither(dal_element *inputDS, memoryPtr *pBase, memoryPtr *pLast, 
		pointingInfoPtr pDither, outputParsPtr pOutput);

void ReadEvents(dal_element *inputDS, memoryPtr *pBase, memoryPtr *pLast, 
		int eventType, char *chantype, char *psdType, 
		short multiplicity, int ntime, OBTime *obStart, OBTime *obStop,
		eventsInfoPtr pEvents, SPI_mode spiMode);
		
gtIntPtr **ReadGT(dal_element *inputDS, memoryPtr *pBase, memoryPtr *pLast, 
	       long nDT, int maxdet, goodTimesPtr pGtimes, long *maxnGTI,  
	       gtRowsPtr pGtrows, int *status);

void ReadPseudoDetTable(memoryPtr *pBase, memoryPtr *pLast, detinfoPtr pDet);

int Rebin(short *countsIn, unsigned char eRange, unsigned short *bounds, 
		int nChans, long *countsOut);

void ReportOutputType(detinfoPtr pDet, outputParsPtr pOutput);

int SelectEvents(dal_element *InputDS, SPI_mode SpiMode, SPI_type EvType,
		int NumIntervals, OBTime *gtiStart, OBTime *gtiStop, 
		char *psdType, char *chanType, int status);
		
void SetDetFlags(detinfoPtr pDet);

void SpecKeywords(dal_element *inputDS, dal_element *pTable, memoryPtr pBase);

int SpihCloseEvents(int current_status);

int SpihGetNumEvents(long *NumEvents, int current_status);

int SpihGetEvents(Event_params  ColID, dal_dataType *ColType, void *ColBuff,
		     int current_status);
		     
int SpihistGetParams(memoryPtr *pBase, char *detnums, dal_element **outGroup,
	       headerParsPtr pHeader, outputParsPtr pOutput, 
	       eventCriteriaPtr pEventcriteria, int *detSumFlag,
	       int *pntSumFlag, char *coeffDOL);
	       
void SpihistOutput(dal_element *inputDS, dal_accessType access, 
		   memoryPtr *pBase, memoryPtr *pLast, int pointingNum,
		   int dcount, ditherPtr *ditherList, gtIntPtr **gtList, 
		   gtRowsPtr pGtrows, outputParsPtr pOutput, binningPtr pBin, 
		   detinfoPtr pDet, headerParsPtr pHeader, int detSumFlag,
		   int pntSumFlag, int totPointings);

void SpihistProcessData(memoryPtr *pBase, memoryPtr *pLast, dal_element 
		*outGroup, headerParsPtr pHeader, outputParsPtr pOutput,
		eventCriteriaPtr pEventscriteria, eventsInfoPtr pEvents,
		binningPtr pBin, detinfoPtr pDet, int *detSumFlag,  int
		*pntSumFlag, char *coeffDOL);
		
int SPImode(dal_element *OG, OBTime time_to_check, short *mode, short *spectra, int status);

int Timehist(binningPtr pBin, detinfoPtr pDet);

int TimeInGT(int pointingNum, int detid, OBTime t0, gtIntPtr **gtList,
		gtRowsPtr pGtrows);

void YraDec(double d_xRa, double d_xDec, double d_zRa, double d_zDec, 
	    double *yRa, double *yDec);


#ifdef  __cplusplus
}
#endif



#endif   /* SPIHIST_INCLUDED */
