/*----------- Function -------------------------------------------------

   Main program for SPIHIST.

------------- Description ----------------------------------------------

   Wrapper for Spihist getParameters and the main Spihist work function, 
   SpihistProcessData.
   
------------- Authors/Modification History: ----------------------------

   Craig Gordon (2.2.0; Sep 02) ; Modifications to conform with CTS 
   					architecture for executables.
				  See Progver.c and spihist.c for the
				  	extensive list of modifications.

------------------------------------------------------------------------   
*/

#include "spihist.h"

/* Global definition of OPER and EMER mode as returned from SPImode */
extern const short gl_oper = 41, gl_emer = 42, gl_undefined = 99;
/* Global definition of pseudotable categories and standard pseudodet table*/
extern const int gl_boundaries[2][6]={{19,61,85,104,123,142},{0,2,3,1,0,0}};
extern const int gl_numbnds=6;
extern const struct multiDetEntry 
   {
      int id;
      char *detcode;
   } gl_standardTable[SPIHIST_NSTND] = 
         {0,"0",1,"1",2,"2",3,"3",4,"4",5,"5",6,"6",7,"7",8,"8",9,"9",10,"10",
	 11,"11",12,"12",13,"13",14,"14",15,"15",16,"16",17,"17",18,"18",
	 19,"20001",20,"20002",21,"20003",22,"20004",23,"20005",24,"20006",
	 25,"20102",26,"20106",27,"20107",28,"20108",29,"20109",30,"20203",
	 31,"20209",32,"20210",33,"20211",34,"20304",35,"20311",36,"20312",
	 37,"20313",38,"20405",39,"20413",40,"20414",41,"20415",42,"20506",
	 43,"20515",44,"20516",45,"20517",46,"20607",47,"20617",48,"20618",
	 49,"20708",50,"20718",51,"20809",52,"20910",53,"21011",54,"21112",
	 55,"21213",56,"21314",57,"21415",58,"21516",59,"21617",60,"21718",
	 61,"3000102",62,"3000203",63,"3000304",64,"3000405",65,"3000506",
	 66,"3000601",67,"3010209",68,"3010607",69,"3010708",70,"3010809",
	 71,"3020311",72,"3020910",73,"3021011",74,"3030413",75,"3031112",
	 76,"3031213",77,"3040515",78,"3041314",79,"3041415",80,"3050617",
	 81,"3051516",82,"3051617",83,"3060718",84,"3061718",
	 85,"1900",86,"1901",87,"1902",88,"1903",89,"1904",90,"1905",91,"1906",
	 92,"1907",93,"1908",94,"1909",95,"1910",96,"1911",97,"1912",98,"1913",
	 99,"1914",100,"1915",101,"1916",102,"1917",103,"1918",
	 104,"1000",105,"1001",106,"1002",107,"1003",108,"1004",109,"1005",
	 110,"1006",111,"1007",112,"1008",113,"1009",114,"1010",115,"1011",
	 116,"1012",117,"1013",118,"1014",119,"1015",120,"1016",121,"1017",
	 122,"1018",123,"1100",124,"1101",125,"1102",126,"1103",127,"1104",
	 128,"1105",129,"1106",130,"1107",131,"1108",132,"1109",133,"1110",
	 134,"1111",135,"1112",136,"1113",137,"1114",138,"1115",139,"1116",
	 140,"1117",141,"1118"};

main(int argc, char *argv[])
{
   memoryPtr         pBase=NULL;
   memoryPtr         pLast=NULL;
   outputParsPtr     pOutput=NULL;
   binningPtr        pBin=NULL;
   detinfoPtr        pDet=NULL;
   eventCriteriaPtr  pEventcriteria=NULL;
   eventsInfoPtr     pEvents=NULL;
   headerParsPtr     pHeader=NULL;
   
   int mode=0, status=ISDC_OK;
   int detSumFlag=0, pntSumFlag=0;
   char program[PROGVER_SIZE];
   char version[PROGVER_SIZE];
   char message[DAL_MAX_STRING];
   char coeffDOL[DAL_MAX_STRING];
   
   dal_element       *outGroup=NULL;

   ProgVer(program, version);
   
   Allocate(program, "-pOutput", 0, sizeof(OUTPUTPARS), (void **) &pOutput,
	    &pBase, &pLast);
   Allocate(program, "-pBin", 0, sizeof(BINNING), (void **) &pBin, &pBase, 
	    &pLast);
   Allocate(program, "-pDet", 0, sizeof(DETINFO), (void **) &pDet, &pBase, 
	    &pLast);
   Allocate(program, "-pEvents", 0, sizeof(EVENTSINFO), (void **) &pEvents,
	    &pBase, &pLast);
   Allocate(program, "-pEventcriteria", 0, sizeof(EVENTCRITERIA),
	    (void **) &pEventcriteria, &pBase, &pLast);
   Allocate(program, "-pHeader", 0, sizeof(HEADERPARS), (void **) &pHeader, 
	    &pBase, &pLast);

   mode = CommonInit("spihist", version, argc, argv);
   if ((mode != ISDC_SINGLE_MODE) && (mode != ISDC_SERVER_MODE))
   {
      status = mode;
      strcpy(message, "Mode must be ISDC_SINGLE_MODE or ISDC_SERVER_MODE");
      Cleanup(status, message, pBase, program);
   }
   InitSpiStr(pOutput, pHeader, pBin, pDet, pEvents, pEventcriteria);

   /* display the SPIHIST VERSION */
   DisplayVersion(program, version, pHeader->tskstr, &pBase, WTCHATTER);

   status = SpihistGetParams(&pBase, pDet->detnums, &outGroup, pHeader, pOutput,
   		pEventcriteria, &detSumFlag, &pntSumFlag, coeffDOL);
   if (status != ISDC_OK)
   {
      Cleanup(status, " ", pBase, program);
   }
   
   /* This function will always call CommonExit upon exiting */
   SpihistProcessData(&pBase, &pLast,  outGroup, pHeader, pOutput, 
   		pEventcriteria, pEvents, pBin, pDet, &detSumFlag, &pntSumFlag,
		coeffDOL);  
}
