/* 
-------- Function: -------------------------------------------------------------

     SpihistOutput


-------- Description: ----------------------------------------------------------

     This program calls calls CreatePHAII for PHA option or DataExtension for
     ISDC output option.


-------- Functions called: -----------------------------------------------------

   Spihist Functions:
      CreatePHA_II       -- Writes output in PHA II format
      DataExtension      -- Writes output in ISDC format


-------- Usage: ----------------------------------------------------------------

   Input Parameters:
       INPUTDS       dal_element     : Pointer to the Observation group DOL
       ACCESS        dal_accessType  : ACCESS_UNKNOWN=-1, DAL_HTTP=1, DAL_FTP=2,
                                       DAL_SHMEM=3, DAL_MEM=4, DAL_DISK=5, 
	 			       DAL_ROOT=6
       PBASE         memoryPtr       : Pointer to the list that keeps track of
                                       allocated memory
       PLAST         memoryPtr       : Pointer to the current node in the list
                                       pointed to by the PBASE
       POINTINGNUM   int             : Index to the pointing 
       DCOUNT        int             : Total number of rows in input POINTING 
                                       extension
       DITHERLIST    ditherPtr       : Each node in this list corresponds to a 
                                       single pointing and contains the 
				       associated x,y,z-ra/dec values
       GTLIST       gtIntPtr      : Structs containing Good Time + Livetime info
       PGTROWS      gtRowsPtr 
              
       DETSUMFLAG   int		   : +1 Indicates all detectors within a
       				     pointing will be summed.
       PNTSUMFLAG   int		   : +1 Indicates each detector is summed
       				     across pointings.
				     A -1 for both indicates both cases
				     are output, along with the normal 
				     individual detector spectra.
       TOTPOINTINGS int		   : The total number of pointings that will
       				     be processed during spihist run.

           outputParsPtr Pars
	   ------------------
       FORMAT        char            : Format for the output file
       CHATTER       int             : Chattiness flag 


-------- Include files ---------------------------------------------------------

   "spihist.h"


-------- Authors/Modification History: -----------------------------------------

   Craig Gordon  (3.0.0; Dec 02) ; removed multipointing option
   Craig Gordon (2.2.0; Sep 02) ;extra parameters passed to CreatePHA_II
   Sandhia Bansal  (1.0.0; June 00)

----------------------------------------------------------------------------- */

#include "spihist.h"



void SpihistOutput(dal_element *inputDS, dal_accessType access, 
		   memoryPtr *pBase, memoryPtr *pLast, int pointingNum,
		   int dcount, ditherPtr *ditherList, gtIntPtr **gtList, 
		   gtRowsPtr pGtrows, outputParsPtr pOutput, binningPtr pBin, 
		   detinfoPtr pDet, headerParsPtr pHeader, int detSumFlag,
		   int pntSumFlag, int totPointings)
{
   
   if (strcmp(pOutput->format, "PHA") == 0)
      CreatePHA_II(inputDS, access, pBase, pLast, pointingNum, dcount, *ditherList, 
		   gtList, pGtrows, pOutput, pBin, pDet, pHeader, detSumFlag, 
		   pntSumFlag, totPointings);

   else 
      DataExtension(inputDS, pBase, pLast, pOutput->chatter, pDet, pHeader); 
		   
}
