/*  This code was originally supplied by Volker Beckmann (Dec 02) 
    for Spihist 3.0.0  It is also used by the program SPIGTI */
    
#include "spihist.h"

int SPImode(dal_element *OG, OBTime time_to_check, short *mode, short *spectra, int status)
{
    #define LIMIT_FOR_SE_KEPT 1.25 /* SE per 125 msec */

    long numModes=0; /* number of modes found */
    int buffsize=0; /* size of buffer to be allocated */
    int i, numfound=0; /* number of elements found in data structure */
    long numfound2 = 0;
    OBTime *OBTmodechange = NULL; /* time of mode change inside requested period */
    OBTime OBTtemp[1]; 
    short *readmode = NULL; 
    dal_element *ScienceWindowGroup = NULL; /* science window group to read the block information */
    dal_element *SWGindex=NULL; /* the index of science window groups */
    dal_element *rawblock=NULL; /* Raw data block SPI.-OBLK-HRW */
    int *single_events = NULL; /* SGLE_NUM as read from SPI.-OBLK-HRW */
    float mean_single= 0.0; /* mean number of SE per 125 msec */
    dal_dataType type;

    double testtime[1]; /* time_to_check in OBT format */
    char mytest[DAL_BIG_STRING]; /* CFITSIO selection string */


    /* read the SPI modes for the given OBTime interval */
    /* get the number of modes inside one time interval */
    status = DAL3HKgetNumMode(OG, "SPI_MODE", time_to_check, time_to_check, &numModes, status);
    if (ISDC_OK != status) {
	RILlogMessage(NULL, Error_2, "Error reading the number of SPI modes. Status %d", status);
	*mode = 99; /* set SPI mode to undefined */
    }
    else {	
	/* RILlogMessage(NULL, Log_2, "Reading %ld modes. Status %d", numModes, status); */

	buffsize = numModes * sizeof(OBTime);
	OBTmodechange = NULL;
	status = DALallocateDataBuffer((void **) &OBTmodechange, buffsize,status);
	buffsize = numModes * sizeof(short);
	status = DALallocateDataBuffer((void **) &readmode, buffsize,status);
	status = DAL3HKgetMode(OG, "SPI_MODE",time_to_check, time_to_check, OBTmodechange, readmode, status);
	if (ISDC_OK != status) {
	    RILlogMessage(NULL, Error_2, "Error reading the SPI mode. Status %d", status);
	    *mode = 99; /* set SPI mode to undefined */
	}
	else {
	  /* RILlogMessage(NULL, Log_2, "%ld modes read [%d]. Status %d", numModes, readmode[0], status); */
	    *mode = readmode[0];
	    /* check whether there is one mode NOT OPERATIONAL */
	    *spectra = 0;
	    if ((*mode) == 42) /* in EMER mode we have spectra */
		*spectra = 1; 
	    if ((*mode) != 41) 
		*mode = 99; /* not OPER, not EMER, set to UNDEFINED */ 
	    else {
		/* So we have OPER mode, now we have to check whether we have spectra or photon-by-photon */
		/* find the science window group index inside the observation group */
		status = DALobjectFindElement(OG,"GNRL-SCWG-GRP-IDX",&SWGindex,status);
		if (status != ISDC_OK)
		    RILlogMessage(NULL, Error_1, "Error accessing the SWG index from the observation group. Status %d", status); 
    

		/* select the SWG which covers the requested start time */
		OBTtemp[0] = time_to_check;
		status = DAL3AUXconvertOBT2IJD(OG, TCOR_ANY, 1, OBTtemp, testtime, status); 
		sprintf(mytest, "TSTART <= %f && %f <= TSTOP", testtime[0], testtime[0]);
		status = DAL3GENindexFindMember(SWGindex, "GNRL-SCWG-GRP",mytest, &numfound, &ScienceWindowGroup, status); 
		if (status != ISDC_OK || numfound>1 || numfound == 0) {
		    RILlogMessage(NULL, Warning_1, "Error accessing the SWG from the science window group index at IJD %f. %d SWG found. Status %d", testtime[0],numfound, status);
		    status = ISDC_OK;
		    if (testtime[0] < 1133.0 && testtime[0] > 1058.3254) {
		      *spectra = 1;
		      RILlogMessage(NULL, Log_1, "status back to 0, spectra = 1");
		    }
		    else {
		      *spectra = 0;
		      RILlogMessage(NULL, Log_1, "status back to 0, spectra = 0");
		    }
		      
		}
		else {
		    
		    /* get a pointer to the SPI.-OBLK-HRW in the current SWG */
		    status = DALobjectFindElement(ScienceWindowGroup,"SPI.-OBLK-HRW",&rawblock,status);
		    if (status != ISDC_OK) {
			RILlogMessage(NULL, Warning_1, "Error while accessing SPI.-OBLK-HRW in IJD = %g. Status %d", testtime[0], status); 
		    status = ISDC_OK;
		    if (testtime[0] < 1133.0 && testtime[0] > 1058.3254) {
			*spectra = 1;
			RILlogMessage(NULL, Log_1, "status back to 0, spectra = 1");
		    }
		    else {
			*spectra = 0;
			RILlogMessage(NULL, Log_1, "status back to 0, spectra = 0");
		    }
		    }
		    else {
			/* read the number of rows of SPI.-OBLK-HRW for this SWG */
			status = DALtableGetNumRows(rawblock,&numfound2,status);
			buffsize = numfound2 * sizeof(int);
			status = DALallocateDataBuffer((void **) &single_events, buffsize,status);
			type = DAL_INT; 
			status = DALtableGetCol(rawblock, "SGLE_NUM", 0, &type, &numfound2, single_events, status);    
			if (status != ISDC_OK) {
			    RILlogMessage(NULL, Error_1, "Error while reading SGLE_NUM from SPI.-OBLK-HRW in SWG. Status %d", status); 
			}
			else {
			    /* determine the mean value of single events per 125 msec */
			    mean_single=0.0;
			    for( i = 0; i<numfound2; ++i)
				mean_single += single_events[i];
			    mean_single /= numfound2;
			    
			    /* if the mean single countrate is larger than the limit defined in spigti.h, then we have photon by photon data */
			    if (mean_single > LIMIT_FOR_SE_KEPT)
				*spectra = 0;
			    else
				*spectra = 1;

			    status = DALfreeDataBuffer( (void *) single_events, status);
			}
		    }
		} 
	    }
	}
    }
    /* RILlogMessage(NULL, Log_2, "Free buffer. Status %d", status); */
    
    status = DALfreeDataBuffer( (void *) OBTmodechange, status);
    status = DALfreeDataBuffer( (void *) readmode, status);

    /* RILlogMessage(NULL, Log_2, "Buffer is free. Status %d", status); */

    return status; 
}
