/* 
-------- Function: -------------------------------------------------------------

     TimeHist


-------- Description: ----------------------------------------------------------

     This subroutine creates the time histories.


-------- Functions called: -----------------------------------------------------

   Spihist Functions:
      IndexToChnl  -- Returns the index in the array such that input value is 
                      contained within array[index] and array[index+1]


-------- Usage: ----------------------------------------------------------------

   void Timehist(binningPtr pBin, detinfoPtr pDet)


   Input Parameters:
               binningPtr pars
	       ---------------
       NENERGY       int          : Number of bins in the binning file
       ENERGY        float        : Array contining bin boundaries read from the
                                    binning file

               detinfoPtr pars
	       ---------------
       DET0          int          : Detector that detected the current event
       DET1          int          : Detector that detected the current event
                                    (for PSD data only)
       PI0           int          : Input energy value


   Output Parameters:

               detinfoPtr pars
	       ---------------
       HIST          long         : Hist[i]!=0 if a histogram was accumulated 
                                    for ith detector
   Return:
   	1  if event was added to bin
	0  if not

-------- Include files ---------------------------------------------------------

   "spihist.h"


-------- Authors/Modification History: -----------------------------------------

   Craig Gordon  (3.0.0; Dec 02)  ; Remove multipointing option, add return val.
   Sandhia Bansal  (1.0.0; Aug 00)


----------------------------------------------------------------------------- */

#include "spihist.h"


int Timehist(binningPtr pBin, detinfoPtr pDet)
{
   int    ich=0, i=0;
   int    eventAdded=0;

   ich = IndexToChnl(pDet->pi0, pBin->nEnergy-1, pBin->energy);

   if (ich >= 0)
   {
      ++(pDet->hist[pDet->det0][ich]);
      eventAdded = 1;
   }
   return eventAdded;
}



