/* 
-------- Function: ------------------------------------------------------------

     TimeInGT


-------- Description: ---------------------------------------------------------

     This subroutine determines whether the input time lies within the valid 
     time range.


-------- Usage: ---------------------------------------------------------------

   int TimeInGT(int pointingNum, int detid, double t0, gtPtr **gtList)


   Input Parameters:
       POINTINGNUM   int      : Index to the pointing read from POINTING ext
       DETID         int      : Pseudo detector id currently being processed
       T0            OBTime   : Input time
       GTLIST        gtIntPtr    : Array containing GOOD TIME information
       PGTROWS        gtRowsPtr  : Additional GTI information

   Output Parameters:
       STATUS        int      : 0=OK


-------- Include files --------------------------------------------------------

   "spihist.h"


-------- Authors/Modification History: ----------------------------------------

		   (3.0.4; Feb 03)  Using new gtInt and gtRows structs.
   Craig Gordon    (2.2.1; Nov 02)  The t0 parameter is now in OBTime format
   					rather than IJD.
   Sandhia Bansal  (1.0.0; Aug 00)


---------------------------------------------------------------------------- */

#include "spihist.h"


int TimeInGT(int pointingNum, int detid, OBTime t0, gtIntPtr **gtList,
		gtRowsPtr pGtrows)
{
   int i, nInts;
   
   nInts = pGtrows->nInts[pointingNum][detid];
   for (i=0; i<nInts; ++i)
   {
      if ((t0 >= gtList[pointingNum][detid][i].obStart) &&
      	  (t0 <= gtList[pointingNum][detid][i].obStop))
	 return(1);
   }
   return(0);

}
