/* 
-------- Function: -------------------------------------------------------------

     YraDec


-------- Description: ----------------------------------------------------------

     This function calculates the y-ra/dec from x,z-ra/dec values.


-------- Usage: ----------------------------------------------------------------
 
   void YraDec(double d_xRa, double d_xDec, double d_zRa, double d_zDec, 
	       double *yRa, double *yDec)

   Input Parameters:	
       D_XRA,D_XDEC, D_ZRA,D_ZDEC     double   : x,z-ra/dec in degrees

				  
   Output Parameters:
       YRA, YDEC                      double   : y-ra/dec in degrees
       

-------- Include files ---------------------------------------------------------

   "spihist.h"


-------- Authors/Modification History: -----------------------------------------

   Sandhia Bansal  (1.0.0; Aug 00)


----------------------------------------------------------------------------- */

#include "spihist.h"


void YraDec(double d_xRa, double d_xDec, double d_zRa, double d_zDec, 
	    double *yRa, double *yDec)
{
   double  a=0;
   double  b=0;
   double  xRa=d_xRa*DEGTORAD, xDec=d_xDec*DEGTORAD;
   double  zRa=d_zRa*DEGTORAD, zDec=d_zDec*DEGTORAD;

   *yDec = asin((cos(zRa)*cos(zDec)*sin(xRa)*cos(xDec)) -
		(sin(zRa)*cos(zDec)*cos(xRa)*cos(xDec)));

   if (cos(*yDec) == 0)
      *yRa = *yDec = 0;

   else
   {
      a = ((sin(zDec)*cos(xRa)*cos(xDec)) - 
	   (cos(zRa)*cos(zDec)*sin(xDec))) / cos(*yDec);

      b = ((sin(zRa)*cos(zDec)*sin(xDec)) -
	   (sin(zDec)*sin(xRa)*cos(xDec))) / cos(*yDec);

      if (b >= 0)
	 *yRa = asin(a);
      else
	 *yRa = _PI - asin(a);
   }

   *yRa  *= RADTODEG;
   *yDec *= RADTODEG;
}
